@@ -42,27 +42,28 @@ class ManageConsumers():
         # Used for storing channel
         self.channel = None
 
+    # Setting Rabbit MQ Connection
     def set_connection(self, new_channel):
         self.connection = new_channel
-
+    # Getting Rabbit MQ Connection
     def get_connection(self):
         return self.connection
-
+    # Setting Consuming Channel
     def set_channel(self, new_channel):
         self.channel = new_channel
-
+    # Getting Rabbit MQ Consuming Channel
     def get_channel(self):
         return self.channel
-
+    # Setting Handler
     def set_handler(self, new_handler):
         self.handler = new_handler
-
+    # Getting Handler
     def get_handler(self):
         return self.handler  
-          
+    # Setting Rabbit MQ Exchange
     def set_exchange(self, new_exchange):
         self.exchange = new_exchange
-
+    # Getting Rabbit MQ Exchange
     def get_exchange(self):
         return self.exchange  
 
@@ -85,12 +86,11 @@ async def service_publish(new_message, routing_key):
 async def callback(message: aio_pika.abc.AbstractIncomingMessage,) -> None:
     consumer = get_consumer()
     new_message = json.loads(message.body)
-    print(str(json.loads(message.body)))
     await service_publish((new_message), consumer.started_job_routing_key)
     handler = consumer.get_handler()
     _response, _status = handler(new_message)
     if _status == True:
-        _logger.info(f"publishing at1 : { consumer.successful_job_routing_key} {new_message}")
+        _logger.info(f"publishing at : { consumer.successful_job_routing_key} {new_message}")
         await service_publish((new_message), consumer.successful_job_routing_key)
     elif _status == False:
         _logger.info(f"publishing at : { consumer.failed_job_routing_key}")
@@ -99,18 +99,21 @@ async def callback(message: aio_pika.abc.AbstractIncomingMessage,) -> None:
     await message.ack(False)
     
 async def main(consumer) -> None:
-    connection = await connect_robust(
-    f"amqp://{consumer.rabbit_user}:{consumer.rabbit_password}@{consumer.rabbit_host}/?name=aio-pika%20worker",
-    )
-    created_channel = await connection.channel()
-    consumer.set_channel(created_channel)
-    await created_channel.set_qos(prefetch_count=1)
-    queue = await created_channel.declare_queue(consumer.queue_name, durable=True)
-    exchange = await created_channel.declare_exchange(name = consumer.exchange_name, type = 'topic', durable=True)
-    consumer.set_exchange(exchange)
-    await queue.bind(exchange, consumer.new_jobs_routing_key)
-    await queue.consume(callback)
-    await asyncio.Future()
+    try:
+        connection = await connect_robust(
+        f"amqp://{consumer.rabbit_user}:{consumer.rabbit_password}@{consumer.rabbit_host}/?name=aio-pika%20worker",
+        )
+        created_channel = await connection.channel()
+        consumer.set_channel(created_channel)
+        await created_channel.set_qos(prefetch_count=1)
+        queue = await created_channel.declare_queue(consumer.queue_name, durable=True)
+        exchange = await created_channel.declare_exchange(name = consumer.exchange_name, type = 'topic', durable=True)
+        consumer.set_exchange(exchange)
+        await queue.bind(exchange, consumer.new_jobs_routing_key)
+        await queue.consume(callback)
+        await asyncio.Future()
+    except Exception as err: 
+        _logger.error("Error in Rabbit MQ: {err}, Message Will Be Comnsumed Again...")
     
 def start_consumer(service_name, handler, rabbit_config):
     consumer = ManageConsumers(service_name, rabbit_config)
